import java.awt.event.*;
import javax.swing.*;
import javax.swing.table.*;
import java.sql.*;
import java.util.*;

/**
 * Implementamos metodos abstractos de AbstractTableModel
 * Sobre-escribimos metodos de AbstractTableModel para customizar
 * JTable
 * Permite hacer ABM sobre la grilla
 * Despliega combo de Producto en grilla, usado en Nueva Factura
 * 
 * @author G. Cherencio
 * @version 1.0
 */
public class DetalleModel  extends AbstractTableModel {
    private List<Detalle> lst = new ArrayList<Detalle>();
    public int getRowCount() {
        return lst.size();
    }
    public int getColumnCount() {
        return 4;
    }
    public Object getValueAt(int row, int column) {
        Detalle c = lst.get(row);
        switch(column) {
            case 0:
                return c.getProducto();
            case 1:
                return c.getCantidad();
            case 2:
                return c.getPrecio();
            case 3:
                return c.getSubTotal();
        }
        return ""+row+","+column;
    }
    @Override
    public String getColumnName(int column) {
        switch(column) {
            case 0:
                return "Producto";
            case 1:
                return "Cantidad";
            case 2:
                return "Precio";
            case 3:
                return "Subtotal";
        }
        return "";
    }
    @Override
    public Class<?> getColumnClass(int columnIndex) {
        switch(columnIndex) {
            case 0:
                return Producto.class;
            case 1:
                return Integer.class;
            case 2:
                return Double.class;
            case 3:
                return Double.class;
        }
        return Object.class;
    }
    @Override
    public boolean isCellEditable(int rowIndex,int columnIndex) {
        switch(columnIndex) {
            case 0:
                return true;
            case 1:
                return true;
            case 2:
                return true;
            case 3:
                return false;
        }
        return false;
    }
    @Override
    public void setValueAt(Object aValue,int rowIndex,int columnIndex) {
        Detalle c = lst.get(rowIndex);
        switch(columnIndex) {
            case 0:
                c.setProducto(((Producto) aValue));
                c.setCantidad(1);
                c.setPrecio(c.getProducto().getPrecio());
                fireTableCellUpdated(rowIndex,1);
                fireTableCellUpdated(rowIndex,2);
                fireTableCellUpdated(rowIndex,3);
                break;
            case 1:
                c.setCantidad((Integer) aValue);
                fireTableCellUpdated(rowIndex,3);
                break;
            case 2:
                c.setPrecio((Double) aValue);
                fireTableCellUpdated(rowIndex,3);
                break;
        }
    }
    
    // METODOS PROPIOS
    // agrega una nueva linea de detalle
    public void agregar() {
        lst.add(new Detalle());
        fireTableDataChanged();
    }
    // borra linea de detalle
    public void borrar(int idx) {
        lst.remove(idx);
        fireTableDataChanged();
    }
}
